# server.py
import os
from mcp.server.fastmcp import FastMCP
import src.cut_video as cut_video
# Create an MCP server
mcp = FastMCP("ffmpeg-mcp")

def is_none_or_empty(s):
    return s is None or s == ""

# Add an addition tool
@mcp.tool()
def find_video_path(root_path, video_name):
    """
    递归查找精确匹配文件名的视频文件路径（支持带或不带扩展名）
    
    参数：
    root_path - 要搜索的根目录
    video_name - 视频文件名（可以带扩展名，但会忽略扩展名匹配）
    
    返回：
    首个匹配的视频文件完整路径，找不到时返回空字符串
    """
    try:
        VIDEO_EXTS = {'.mp4', '.avi', '.mov', '.mkv', '.flv', '.wmv', '.webm'}
        target_stem, target_ext = os.path.splitext(video_name)  # 关键修改：提取主文件名
        for entry in os.listdir(root_path):
            current_path = os.path.join(root_path, entry)
            if os.path.isfile(current_path):
                stem, ext = os.path.splitext(entry)
                if stem.lower() == target_stem.lower():
                    if (is_none_or_empty(target_ext) and is_none_or_empty(ext)):
                        return current_path
                    if (not is_none_or_empty(target_ext) and not is_none_or_empty(ext)):
                        if (ext.lower() == target_ext.lower()):
                            return current_path
                    if (is_none_or_empty(target_ext) and not is_none_or_empty(ext)):
                        if (ext.lower() in VIDEO_EXTS):
                            return current_path
                    if (not is_none_or_empty(target_ext) and is_none_or_empty(ext)):
                        return current_path
                    
            elif os.path.isdir(current_path):
            # 递归搜索子目录
                result = find_video_path(current_path, video_name)
                if result:
                    return result
        return ""
    except Exception as e:
        print(f"find_video_path 发生异常{str(e)}")
        return ""

def handle_log(line: str):
        if "frame=" in line:
            print("进度更新:", line.strip())
        elif "error" in line.lower():
            print("错误信息:", line.strip())

@mcp.tool()
def clip_video(video_path, start=None, end=None,duration = None, output_path=None,time_out=300):
    """
    智能视频剪辑函数
    
    参数：
    video_path : str - 源视频文件路径
    start : int/float/str - 开始时间（支持秒数、MM:SS、HH:MM:SS格式,默认为视频开头,如果不传该参数，或者该参数为负数，从视频结尾往前剪辑）
    end : int/float/str - 结束时间（同上，默认为视频结尾）
    duration:  int/float/str - 裁剪时长，end和duration必须有一个
    output_path: str - 裁剪后视频输出路径，如果不传入，会有一个默认的输出路径
    time_out: int - 命令行执行超时时间，默认为300s
    返回：
    error - 错误码
    str - ffmpeg执行过程中所有日志
    str - 生成的剪辑文件路径
    示例：
    clip_video("input.mp4", "00:01:30", "02:30")
    """
    return cut_video.clip_video_ffmpeg(video_path,start=start,end=end,duration=duration, output_path=output_path,time_out=time_out)   

if __name__ == "__main__":
   print("Server running")
   mcp.run(transport='stdio')